<!--
** Please read **

* Do not report bugs that are specific to your model repository source here.

* Before opening a new issue, make sure to search for keywords in the issues
  list and verify the issue you're about to submit isn't a duplicate:

- internal: https://gitlab.science.gc.ca/CanESM/imsi/-/issues
- external: https://gitlab.com/cccma/imsi/-/issues
-->

## Summary

<!-- Provide a short summary of the bug encountered. -->

### Current `bug` behaviour

<!-- Describe what actually happens. -->

### Expected `correct` behaviour

<!-- Describe what you should see instead. -->

### Steps to reproduce

<!-- Describe how to reproduce the issue - use a numbered list. -->

1.
2.

<!-- Where appropriate:
- Add link to a branch with this error or other supporting pages.
- Add relevant screenshots, logs, code, or output.
-->

<!-- v OPTIONAL, uncomment title v -->
<!-- ## Possible fixes -->

<!--
Provide a link to the line of code that might be responsible for the problem; and/or suggest a fix.
-->

## Environment

<!-- Include the version of imsi you used (run `which imsi`). -->
**imsi version**:

<!-- Leave this label, do not add others -->
/label ~"bug"
